﻿ -- Table: request_type

-- DROP TABLE request_type;

CREATE TABLE request_type
(
  id integer NOT NULL,
  description text,
  CONSTRAINT request_type_pk PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_type
  OWNER TO postgres;


-- Table: service_enquiry_status

-- DROP TABLE service_enquiry_status;

CREATE TABLE service_enquiry_status
(
  id serial NOT NULL,
  description text,
  weighting integer,
  CONSTRAINT service_enquiry_status_pkey PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE service_enquiry_status
  OWNER TO postgres;

-- Table: action_type

-- DROP TABLE action_type;

CREATE TABLE action_type
(
  id serial NOT NULL,
  description text,
  enq_status_modifier integer,
  solo boolean NOT NULL DEFAULT false,
  CONSTRAINT action_type_pkey PRIMARY KEY (id),
  CONSTRAINT action_type_serv_enq_status FOREIGN KEY (enq_status_modifier)
      REFERENCES service_enquiry_status (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE action_type
  OWNER TO postgres;

  

-- Table: action_priority

-- DROP TABLE action_priority;

CREATE TABLE action_priority
(
  id serial NOT NULL,
  description text,
  CONSTRAINT action_priority_pkey PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE action_priority
  OWNER TO postgres;


-- Above needed on a brand new database 

--
-- Name: action_to_request_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE action_to_request_map (
    id integer NOT NULL,
    action_id integer,
    request_id integer
);


ALTER TABLE public.action_to_request_map OWNER TO postgres;

--
-- Name: action_to_request_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE action_to_request_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.action_to_request_map_id_seq OWNER TO postgres;

--
-- Name: action_to_request_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE action_to_request_map_id_seq OWNED BY action_to_request_map.id;


--
-- Name: action_to_service_enquiry_type_actions_template_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE action_to_service_enquiry_type_actions_template_map (
    id integer NOT NULL,
    action_id integer,
    service_enquiry_type_actions_template_id integer
);


ALTER TABLE public.action_to_service_enquiry_type_actions_template_map OWNER TO postgres;

--
-- Name: action_to_service_enquiry_type_actions_template_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE action_to_service_enquiry_type_actions_template_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.action_to_service_enquiry_type_actions_template_map_id_seq OWNER TO postgres;

--
-- Name: action_to_service_enquiry_type_actions_template_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE action_to_service_enquiry_type_actions_template_map_id_seq OWNED BY action_to_service_enquiry_type_actions_template_map.id;


--
-- Name: address; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE address (
    id integer NOT NULL,
    description text NOT NULL,
    lat numeric(20,17),
    lng numeric(20,17),
    optlock integer DEFAULT 0 NOT NULL,
    postcode text
);


ALTER TABLE public.address OWNER TO postgres;

-- Add name to address field to cater for site names better
ALTER TABLE address  ADD COLUMN name text;

--
-- Name: address_category; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE address_category (
    id integer NOT NULL,
    description text
);


ALTER TABLE public.address_category OWNER TO postgres;

--
-- Name: address_category_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE address_category_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.address_category_id_seq OWNER TO postgres;

--
-- Name: address_category_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE address_category_id_seq OWNED BY address_category.id;


--
-- Name: address_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE address_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.address_id_seq OWNER TO postgres;

--
-- Name: address_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE address_id_seq OWNED BY address.id;


--
-- Name: address_to_contact_detail_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE address_to_contact_detail_map (
    id integer NOT NULL,
    address_id integer,
    contact_detail_id integer
);


ALTER TABLE public.address_to_contact_detail_map OWNER TO postgres;

--
-- Name: address_to_contact_detail_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE address_to_contact_detail_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.address_to_contact_detail_map_id_seq OWNER TO postgres;

--
-- Name: address_to_contact_detail_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE address_to_contact_detail_map_id_seq OWNED BY address_to_contact_detail_map.id;


--
-- Name: business_entity; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity (
    id integer NOT NULL,
    business_entity_id integer,
    optlock integer DEFAULT 0 NOT NULL,
    logo text,
    lft integer,
    rgt integer,
    name text
);


ALTER TABLE public.business_entity OWNER TO postgres;

--
-- Name: business_entity_branch; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_branch (
    id integer NOT NULL,
    description text NOT NULL,
    business_entity_id integer NOT NULL,
    address_id integer NOT NULL,
    contact_id integer NOT NULL,
    optlock integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.business_entity_branch OWNER TO postgres;

--
-- Name: business_entity_branch_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_branch_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_branch_id_seq OWNER TO postgres;

--
-- Name: business_entity_branch_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_branch_id_seq OWNED BY business_entity_branch.id;


--
-- Name: business_entity_category; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_category (
    id integer NOT NULL,
    description text
);


ALTER TABLE public.business_entity_category OWNER TO postgres;

--
-- Name: business_entity_category_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_category_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_category_id_seq OWNER TO postgres;

--
-- Name: business_entity_category_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_category_id_seq OWNED BY business_entity_category.id;


--
-- Name: business_entity_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_id_seq OWNER TO postgres;

--
-- Name: business_entity_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_id_seq OWNED BY business_entity.id;


--
-- Name: business_entity_originator; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_originator (
    id integer NOT NULL,
    originator_id integer NOT NULL,
    business_entity_id integer NOT NULL,
    optlock integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.business_entity_originator OWNER TO postgres;

--
-- Name: business_entity_product; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_product (
    id serial NOT NULL,
    business_entity_id integer NOT NULL,
    optlock integer DEFAULT 0 NOT NULL,
    jemser_product_id integer NOT NULL,
    lft integer,
    rgt integer
);


ALTER TABLE public.business_entity_product OWNER TO postgres;

--
-- Name: business_entity_relationship; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_relationship (
    id integer NOT NULL,
    source_business_entity_id integer NOT NULL,
    business_entity_category_id integer NOT NULL,
    target_business_entity_id integer NOT NULL
);


ALTER TABLE public.business_entity_relationship OWNER TO postgres;

-- add seq to business_entity_relationship so we and order prioritys that way.

ALTER TABLE business_entity_relationship ADD COLUMN seq integer;

--
-- Name: TABLE business_entity_relationship; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE business_entity_relationship IS 'This defines for any business entity which other business entities it has a relationship with and what that relationship is.';


--
-- Name: COLUMN business_entity_relationship.source_business_entity_id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN business_entity_relationship.source_business_entity_id IS 'The owner of the relationship';


--
-- Name: COLUMN business_entity_relationship.target_business_entity_id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN business_entity_relationship.target_business_entity_id IS 'The entity with whom we the source_business_entity has a relationship';


--
-- Name: business_entity_relationship_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_relationship_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_relationship_id_seq OWNER TO postgres;

--
-- Name: business_entity_relationship_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_relationship_id_seq OWNED BY business_entity_relationship.id;


--
-- Name: business_entity_to_address_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_to_address_map (
    id integer NOT NULL,
    business_entity_id integer,
    address_id integer,
    address_category_id integer,
    active boolean
);


ALTER TABLE public.business_entity_to_address_map OWNER TO postgres;

--
-- Name: business_entity_to_address_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_to_address_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_to_address_map_id_seq OWNER TO postgres;

--
-- Name: business_entity_to_address_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_to_address_map_id_seq OWNED BY business_entity_to_address_map.id;
ALTER TABLE business_entity_to_address_map
  ADD COLUMN business_entity_to_address_map_id integer;
ALTER TABLE business_entity_to_address_map
  ADD COLUMN reference text;
ALTER TABLE business_entity_to_address_map
  ADD CONSTRAINT betam_betam_fk FOREIGN KEY (business_entity_to_address_map_id) REFERENCES business_entity_to_address_map (id) ON UPDATE NO ACTION ON DELETE NO ACTION;


--
-- Name: business_entity_to_person_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE business_entity_to_person_map (
    id integer NOT NULL,
    business_entity_id integer,
    person_id integer,
    person_role_id integer,
    active boolean
);


ALTER TABLE public.business_entity_to_person_map OWNER TO postgres;

--
-- Name: business_entity_to_person_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE business_entity_to_person_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.business_entity_to_person_map_id_seq OWNER TO postgres;

--
-- Name: business_entity_to_person_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE business_entity_to_person_map_id_seq OWNED BY business_entity_to_person_map.id;


--
-- Name: contact_detail; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE contact_detail (
    id integer NOT NULL,
    contact_detail_category_id integer,
    detail_data text
);


ALTER TABLE public.contact_detail OWNER TO postgres;

--
-- Name: contact_detail_category; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE contact_detail_category (
    id integer NOT NULL,
    description text
);


ALTER TABLE public.contact_detail_category OWNER TO postgres;

--
-- Name: contact_detail_category_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE contact_detail_category_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.contact_detail_category_id_seq OWNER TO postgres;

--
-- Name: contact_detail_category_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE contact_detail_category_id_seq OWNED BY contact_detail_category.id;


--
-- Name: contact_detail_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE contact_detail_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.contact_detail_id_seq OWNER TO postgres;

--
-- Name: contact_detail_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE contact_detail_id_seq OWNED BY contact_detail.id;


--
-- Name: hireco_product_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE hireco_product_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.hireco_product_id_seq OWNER TO postgres;

--
-- Name: hireco_product_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE hireco_product_id_seq OWNED BY business_entity_product.id;


--
-- Name: message; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE message (
    id integer NOT NULL,
    request_id integer NOT NULL,
    message_text text NOT NULL,
    created_by_id integer NOT NULL,
    business_entity_branch_id integer NOT NULL,
    created_at timestamp without time zone NOT NULL,
    viewed_at timestamp without time zone NOT NULL,
    optlock integer DEFAULT 0 NOT NULL,
    in_response_to_message_id integer,
    thread_id integer
);


ALTER TABLE public.message OWNER TO postgres;

--
-- Name: TABLE message; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE message IS 'trewtrew re erwerte wrt';


--
-- Name: COLUMN message.request_id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN message.request_id IS 'gdgdfgdsg';


--
-- Name: message_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE message_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.message_id_seq OWNER TO postgres;

--
-- Name: message_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE message_id_seq OWNED BY message.id;


--
-- Name: originator; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE originator (
    id integer NOT NULL,
    person_id integer,
    notification_platform text,
    notification_token text,
    optlock integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.originator OWNER TO postgres;

--
-- Name: originator_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE originator_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.originator_id_seq OWNER TO postgres;

--
-- Name: originator_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE originator_id_seq OWNED BY originator.id;


--
-- Name: person; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE person (
    id integer NOT NULL,
    name text,
    photo text,
    optlock integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.person OWNER TO postgres;

--
-- Name: person_group; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE person_group (
    id integer NOT NULL,
    person_group_category_id integer,
    person_id integer
);


ALTER TABLE public.person_group OWNER TO postgres;

--
-- Name: person_group_category; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE person_group_category (
    id integer NOT NULL,
    description text
);


ALTER TABLE public.person_group_category OWNER TO postgres;

--
-- Name: person_group_category_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE person_group_category_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.person_group_category_id_seq OWNER TO postgres;

--
-- Name: person_group_category_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE person_group_category_id_seq OWNED BY person_group_category.id;


--
-- Name: person_group_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE person_group_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.person_group_id_seq OWNER TO postgres;

--
-- Name: person_group_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE person_group_id_seq OWNED BY person_group.id;


--
-- Name: person_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE person_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.person_id_seq OWNER TO postgres;

--
-- Name: person_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE person_id_seq OWNED BY person.id;


--
-- Name: person_role; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE person_role (
    id integer NOT NULL,
    description text NOT NULL
);


ALTER TABLE public.person_role OWNER TO postgres;

--
-- Name: person_to_contact_detail_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE person_to_contact_detail_map (
    id integer NOT NULL,
    person_id integer,
    contact_detail_id integer
);


ALTER TABLE public.person_to_contact_detail_map OWNER TO postgres;

--
-- Name: person_to_contact_detail_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE person_to_contact_detail_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.person_to_contact_detail_map_id_seq OWNER TO postgres;

--
-- Name: person_to_contact_detail_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE person_to_contact_detail_map_id_seq OWNED BY person_to_contact_detail_map.id;


--
-- Name: jemser_product; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE jemser_product (
    id integer NOT NULL,
    description text,
    jemser_product_id integer,
    optlock integer DEFAULT 0 NOT NULL,
    product_group_id integer NOT NULL,
    lft integer,
    rgt integer
);


ALTER TABLE public.jemser_product OWNER TO postgres;

--
-- Name: product_accessory; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE product_accessory (
    id integer NOT NULL,
    jemser_product_id integer NOT NULL,
    accessory_id integer NOT NULL,
    optlock integer DEFAULT 0 NOT NULL,
    mandatory boolean NOT NULL
);


ALTER TABLE public.product_accessory OWNER TO postgres;

--
-- Name: product_accessory_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE product_accessory_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.product_accessory_id_seq OWNER TO postgres;

--
-- Name: product_accessory_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE product_accessory_id_seq OWNED BY product_accessory.id;


--
-- Name: product_class; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE product_class (
    id integer NOT NULL,
    product_class_id integer,
    description text,
    lft integer,
    rgt integer
);


ALTER TABLE public.product_class OWNER TO postgres;

--
-- Name: product_class_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE product_class_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.product_class_id_seq OWNER TO postgres;

--
-- Name: product_class_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE product_class_id_seq OWNED BY product_class.id;


--
-- Name: product_group; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE product_group (
    id integer NOT NULL,
    description text,
    product_group_id integer NOT NULL,
    optlock integer DEFAULT 0 NOT NULL,
    icon text,
    lft integer,
    rgt integer,
    product_class_id integer
);


ALTER TABLE public.product_group OWNER TO postgres;

--
-- Name: product_group_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE product_group_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.product_group_id_seq OWNER TO postgres;

--
-- Name: product_group_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE product_group_id_seq OWNED BY product_group.id;


--
-- Name: jemser_product_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE jemser_product_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.jemser_product_id_seq OWNER TO postgres;

--
-- Name: product_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE jemser_product_id_seq OWNED BY jemser_product.id;


--
-- Name: project; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE jemser_project (
    id integer NOT NULL,
    description text,
    business_entity_id integer,
    jemser_project_id integer,
    optlock integer DEFAULT 0 NOT NULL,
    lft integer,
    rgt integer
);


ALTER TABLE public.jemser_project OWNER TO postgres;

--
-- Name: project_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE jemser_project_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.jemser_project_id_seq OWNER TO postgres;

--
-- Name: project_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE jemser_project_id_seq OWNED BY jemser_project.id;


--
-- Name: project_to_address_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE project_to_address_map (
    id integer NOT NULL,
    jemser_project_id integer,
    address_id integer,
    address_category_id integer
);


ALTER TABLE public.project_to_address_map OWNER TO postgres;

--
-- Name: project_to_address_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE project_to_address_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.project_to_address_map_id_seq OWNER TO postgres;

--
-- Name: project_to_address_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE project_to_address_map_id_seq OWNED BY project_to_address_map.id;


--
-- Name: project_to_person_map; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE project_to_person_map (
    id integer NOT NULL,
    jemser_project_id integer,
    person_id integer,
    person_role_id integer
);


ALTER TABLE public.project_to_person_map OWNER TO postgres;

--
-- Name: project_to_person_map_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE project_to_person_map_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.project_to_person_map_id_seq OWNER TO postgres;

--
-- Name: project_to_person_map_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE project_to_person_map_id_seq OWNED BY project_to_person_map.id;


--
-- Name: region; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

--CREATE TABLE region (
--    id integer NOT NULL,
--    description text,
--    optlock integer DEFAULT 0 NOT NULL
--);


--ALTER TABLE public.region OWNER TO postgres;

--
-- Name: region_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

--CREATE SEQUENCE region_id_seq
--    START WITH 1
 --   INCREMENT BY 1
--    NO MINVALUE
--    NO MAXVALUE
--    CACHE 1;


--ALTER TABLE public.region_id_seq OWNER TO postgres;

--
-- Name: region_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

--ALTER SEQUENCE region_id_seq OWNED BY region.id;


--
-- Name: request; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--



-- DROP TABLE request;

CREATE TABLE request
(
  id integer NOT NULL,
  business_entity_id integer,
  note text,
  selected_response_id integer,
  required_date timestamp with time zone,
  creation_date timestamp with time zone,
  optlock integer NOT NULL DEFAULT 0,
  request_status_id integer,
  address_id integer,
  person_id integer,
  request_id integer

)
WITH (
  OIDS=FALSE
);
ALTER TABLE request
  OWNER TO postgres;

-- Index: fki_request_address_fk

-- DROP INDEX fki_request_address_fk;






ALTER TABLE public.request OWNER TO postgres;

ALTER TABLE request ADD CONSTRAINT request_id_to_request_fkey FOREIGN KEY (request_id) REFERENCES request (id)
ON UPDATE NO ACTION ON DELETE NO ACTION;
CREATE INDEX fki_request_id_to_request_fkey
  ON request(request_id);






--
-- Name: request_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE request_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.request_id_seq OWNER TO postgres;

--
-- Name: request_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE request_id_seq OWNED BY request.id;


--
-- Name: request_response; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE request_response (
    id integer NOT NULL,
    request_id integer NOT NULL,
    business_entity_id integer NOT NULL,
    daily numeric(12,2) NOT NULL,
    weekly numeric(12,2) NOT NULL,
    sales numeric(12,2) NOT NULL,
    responded_at timestamp without time zone
);


ALTER TABLE public.request_response OWNER TO postgres;

--
-- Name: request_response_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE request_response_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.request_response_id_seq OWNER TO postgres;

--
-- Name: request_response_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE request_response_id_seq OWNED BY request_response.id;


--
-- Name: request_status; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE request_status (
    id integer NOT NULL,
    description text NOT NULL
);


ALTER TABLE public.request_status OWNER TO postgres;

--
-- Name: request_status_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE request_status_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.request_status_id_seq OWNER TO postgres;

--
-- Name: request_status_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE request_status_id_seq OWNED BY request_status.id;


--
-- Name: role_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE role_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.role_id_seq OWNER TO postgres;

--
-- Name: role_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE role_id_seq OWNED BY person_role.id;


--
-- Name: tender; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE jemser_tender (
    id integer NOT NULL,
    business_entity_id integer,
    jemser_product_id integer NOT NULL,
    region_id integer,
    optlock integer DEFAULT 0 NOT NULL,
    daily numeric(12,2) NOT NULL,
    weekly numeric(12,2) NOT NULL,
    sales numeric(12,2)
);


ALTER TABLE public.jemser_tender OWNER TO postgres;

-- link a tender to a supplier and customer relationship
ALTER TABLE jemser_tender ADD COLUMN business_entity_relationship_id integer;

-- add seq to allow ordering of tenders for a specific jemser product.

ALTER TABLE jemser_tender ADD COLUMN seq integer;

--
-- Name: tender_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE jemser_tender_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.jemser_tender_id_seq OWNER TO postgres;

--
-- Name: tender_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE jemser_tender_id_seq OWNED BY jemser_tender.id;


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY action_to_request_map ALTER COLUMN id SET DEFAULT nextval('action_to_request_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY action_to_service_enquiry_type_actions_template_map ALTER COLUMN id SET DEFAULT nextval('action_to_service_enquiry_type_actions_template_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address ALTER COLUMN id SET DEFAULT nextval('address_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address_category ALTER COLUMN id SET DEFAULT nextval('address_category_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address_to_contact_detail_map ALTER COLUMN id SET DEFAULT nextval('address_to_contact_detail_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity ALTER COLUMN id SET DEFAULT nextval('business_entity_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_branch ALTER COLUMN id SET DEFAULT nextval('business_entity_branch_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_category ALTER COLUMN id SET DEFAULT nextval('business_entity_category_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_relationship ALTER COLUMN id SET DEFAULT nextval('business_entity_relationship_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_address_map ALTER COLUMN id SET DEFAULT nextval('business_entity_to_address_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_person_map ALTER COLUMN id SET DEFAULT nextval('business_entity_to_person_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY contact_detail ALTER COLUMN id SET DEFAULT nextval('contact_detail_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY contact_detail_category ALTER COLUMN id SET DEFAULT nextval('contact_detail_category_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message ALTER COLUMN id SET DEFAULT nextval('message_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY originator ALTER COLUMN id SET DEFAULT nextval('originator_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person ALTER COLUMN id SET DEFAULT nextval('person_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_group ALTER COLUMN id SET DEFAULT nextval('person_group_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_group_category ALTER COLUMN id SET DEFAULT nextval('person_group_category_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_role ALTER COLUMN id SET DEFAULT nextval('role_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_to_contact_detail_map ALTER COLUMN id SET DEFAULT nextval('person_to_contact_detail_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_product ALTER COLUMN id SET DEFAULT nextval('jemser_product_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_accessory ALTER COLUMN id SET DEFAULT nextval('product_accessory_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_class ALTER COLUMN id SET DEFAULT nextval('product_class_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_group ALTER COLUMN id SET DEFAULT nextval('product_group_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_project ALTER COLUMN id SET DEFAULT nextval('jemser_project_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_address_map ALTER COLUMN id SET DEFAULT nextval('project_to_address_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_person_map ALTER COLUMN id SET DEFAULT nextval('project_to_person_map_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

--ALTER TABLE ONLY region ALTER COLUMN id SET DEFAULT nextval('region_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request ALTER COLUMN id SET DEFAULT nextval('request_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request_response ALTER COLUMN id SET DEFAULT nextval('request_response_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request_status ALTER COLUMN id SET DEFAULT nextval('request_status_id_seq'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_tender ALTER COLUMN id SET DEFAULT nextval('jemser_tender_id_seq'::regclass);


--
-- Name: address_category_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY address_category
    ADD CONSTRAINT address_category_pk PRIMARY KEY (id);


--
-- Name: address_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY address
    ADD CONSTRAINT address_pk PRIMARY KEY (id);


--
-- Name: atcdm_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY address_to_contact_detail_map
    ADD CONSTRAINT atcdm_pk PRIMARY KEY (id);


--
-- Name: atrm_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY action_to_request_map
    ADD CONSTRAINT atrm_pk PRIMARY KEY (id);


--
-- Name: atseatm_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY action_to_service_enquiry_type_actions_template_map
    ADD CONSTRAINT atseatm_pk PRIMARY KEY (id);


--
-- Name: bec_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_category
    ADD CONSTRAINT bec_pk PRIMARY KEY (id);


--
-- Name: beta_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_to_address_map
    ADD CONSTRAINT beta_pk PRIMARY KEY (id);


--
-- Name: betpm_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_to_person_map
    ADD CONSTRAINT betpm_pk PRIMARY KEY (id);


--
-- Name: business_entity_branch_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_branch
    ADD CONSTRAINT business_entity_branch_pk PRIMARY KEY (id);


--
-- Name: business_entity_originator_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_originator
    ADD CONSTRAINT business_entity_originator_pk PRIMARY KEY (id);


--
-- Name: business_entity_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity
    ADD CONSTRAINT business_entity_pk PRIMARY KEY (id);


--
-- Name: business_entity_product_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_product
    ADD CONSTRAINT business_entity_product_pk PRIMARY KEY (id);


--
-- Name: busniess_entity_relationship_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY business_entity_relationship
    ADD CONSTRAINT busniess_entity_relationship_pk PRIMARY KEY (id);


--
-- Name: contact_detail_category_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY contact_detail_category
    ADD CONSTRAINT contact_detail_category_pk PRIMARY KEY (id);


--
-- Name: contact_detail_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY contact_detail
    ADD CONSTRAINT contact_detail_pk PRIMARY KEY (id);


--
-- Name: message_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY message
    ADD CONSTRAINT message_pk PRIMARY KEY (id);


--
-- Name: originator_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY originator
    ADD CONSTRAINT originator_pk PRIMARY KEY (id);


--
-- Name: person_group_category_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY person_group_category
    ADD CONSTRAINT person_group_category_pk PRIMARY KEY (id);


--
-- Name: person_group_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY person_group
    ADD CONSTRAINT person_group_pk PRIMARY KEY (id);


--
-- Name: person_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY person
    ADD CONSTRAINT person_pk PRIMARY KEY (id);


--
-- Name: person_to_contact_detail_map_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY person_to_contact_detail_map
    ADD CONSTRAINT person_to_contact_detail_map_pk PRIMARY KEY (id);


--
-- Name: product_accessory_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY product_accessory
    ADD CONSTRAINT product_accessory_pk PRIMARY KEY (id);


--
-- Name: product_class_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY product_class
    ADD CONSTRAINT product_class_pk PRIMARY KEY (id);


--
-- Name: product_group_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY product_group
    ADD CONSTRAINT product_group_pk PRIMARY KEY (id);


--
-- Name: jemser_product_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY jemser_product
    ADD CONSTRAINT jemser_product_pk PRIMARY KEY (id);


--
-- Name: project_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY jemser_project
    ADD CONSTRAINT jemser_project_pk PRIMARY KEY (id);


--
-- Name: ptam; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY project_to_address_map
    ADD CONSTRAINT ptam PRIMARY KEY (id);


--
-- Name: ptpm_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY project_to_person_map
    ADD CONSTRAINT ptpm_pk PRIMARY KEY (id);


--
-- Name: region_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

--ALTER TABLE ONLY region
--    ADD CONSTRAINT region_pk PRIMARY KEY (id);


--
-- Name: request_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY request
    ADD CONSTRAINT request_pk PRIMARY KEY (id);


--
-- Name: request_response_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY request_response
    ADD CONSTRAINT request_response_pk PRIMARY KEY (id);


--
-- Name: request_status_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY request_status
    ADD CONSTRAINT request_status_pk PRIMARY KEY (id);


--
-- Name: role_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY person_role
    ADD CONSTRAINT role_pk PRIMARY KEY (id);


--
-- Name: tender_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY jemser_tender
    ADD CONSTRAINT jemser_tender_pk PRIMARY KEY (id);


--
-- Name: bus_entity_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX bus_entity_celko ON business_entity USING btree (lft, rgt);


--
-- Name: bus_prod_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX bus_prod_celko ON business_entity_product USING btree (lft, rgt);


--
-- Name: fki_prod_group_fk2; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX fki_prod_group_fk2 ON product_group USING btree (product_class_id);


--
-- Name: fki_product_class_fk; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX fki_product_class_fk ON product_class USING btree (product_class_id);


--
-- Name: fki_request_address_fk; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX fki_request_address_fk ON request USING btree (address_id);


--
-- Name: jemser_product_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX jemser_product_celko ON jemser_product USING btree (lft, rgt);


--
-- Name: product_class_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX product_class_celko ON product_class USING btree (lft, rgt);


--
-- Name: product_g_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX product_g_celko ON product_group USING btree (lft, rgt);


--
-- Name: project_celko; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX project_celko ON jemser_project USING btree (lft, rgt);


--
-- Name: atcdm_address_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address_to_contact_detail_map
    ADD CONSTRAINT atcdm_address_fk FOREIGN KEY (address_id) REFERENCES address(id);


--
-- Name: atcdm_contact_detail_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address_to_contact_detail_map
    ADD CONSTRAINT atcdm_contact_detail_fk FOREIGN KEY (contact_detail_id) REFERENCES contact_detail(id);


--
-- Name: atrm_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY action_to_request_map
    ADD CONSTRAINT atrm_fk FOREIGN KEY (request_id) REFERENCES request(id);


--
-- Name: ber_business_entity_category_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_relationship
    ADD CONSTRAINT ber_business_entity_category_fk FOREIGN KEY (business_entity_category_id) REFERENCES business_entity_category(id) DEFERRABLE;


--
-- Name: betam_address_category_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_address_map
    ADD CONSTRAINT betam_address_category_fk FOREIGN KEY (address_category_id) REFERENCES address_category(id);


--
-- Name: betam_address_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_address_map
    ADD CONSTRAINT betam_address_fk FOREIGN KEY (address_id) REFERENCES address(id);


--
-- Name: betam_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_address_map
    ADD CONSTRAINT betam_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id);


--
-- Name: betpm_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_person_map
    ADD CONSTRAINT betpm_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id);


--
-- Name: betpm_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_person_map
    ADD CONSTRAINT betpm_person_fk FOREIGN KEY (person_id) REFERENCES person(id);


--
-- Name: betpm_person_role_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_to_person_map
    ADD CONSTRAINT betpm_person_role_fk FOREIGN KEY (person_role_id) REFERENCES person_role(id);


--
-- Name: business_entity_branch_address_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_branch
    ADD CONSTRAINT business_entity_branch_address_fk FOREIGN KEY (address_id) REFERENCES address(id) DEFERRABLE;


--
-- Name: business_entity_branch_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_branch
    ADD CONSTRAINT business_entity_branch_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: business_entity_branch_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_branch
    ADD CONSTRAINT business_entity_branch_person_fk FOREIGN KEY (contact_id) REFERENCES person(id) DEFERRABLE;


--
-- Name: business_entity_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity
    ADD CONSTRAINT business_entity_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: business_entity_originator_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_originator
    ADD CONSTRAINT business_entity_originator_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: business_entity_originator_originator_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_originator
    ADD CONSTRAINT business_entity_originator_originator_fk FOREIGN KEY (originator_id) REFERENCES originator(id) DEFERRABLE;


--
-- Name: business_entity_product_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_product
    ADD CONSTRAINT business_entity_product_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id);


--
-- Name: cd_to_cd_category_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY contact_detail
    ADD CONSTRAINT cd_to_cd_category_fk FOREIGN KEY (contact_detail_category_id) REFERENCES contact_detail_category(id);


--
-- Name: mesage_message_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message
    ADD CONSTRAINT mesage_message_fk FOREIGN KEY (in_response_to_message_id) REFERENCES message(id);


--
-- Name: message_business_entity_branch_id; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message
    ADD CONSTRAINT message_business_entity_branch_id FOREIGN KEY (business_entity_branch_id) REFERENCES business_entity_branch(id);


--
-- Name: message_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message
    ADD CONSTRAINT message_person_fk FOREIGN KEY (created_by_id) REFERENCES person(id);


--
-- Name: message_request_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message
    ADD CONSTRAINT message_request_fk FOREIGN KEY (request_id) REFERENCES request(id) DEFERRABLE;


--
-- Name: message_thread_message_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY message
    ADD CONSTRAINT message_thread_message_fk FOREIGN KEY (thread_id) REFERENCES message(id);


--
-- Name: originator_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY originator
    ADD CONSTRAINT originator_person_fk FOREIGN KEY (person_id) REFERENCES person(id) DEFERRABLE;


--
-- Name: patm_address_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_address_map
    ADD CONSTRAINT patm_address_fk FOREIGN KEY (address_id) REFERENCES address(id);


--
-- Name: patm_project_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_address_map
    ADD CONSTRAINT patm_project_fk FOREIGN KEY (jemser_project_id) REFERENCES jemser_project(id);


--
-- Name: pg_pg_category_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_group
    ADD CONSTRAINT pg_pg_category_fk FOREIGN KEY (person_group_category_id) REFERENCES person_group_category(id);


--
-- Name: prod_group_fk2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_group
    ADD CONSTRAINT prod_group_fk2 FOREIGN KEY (product_class_id) REFERENCES product_class(id);


--
-- Name: product_accessory_accessory_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_accessory
    ADD CONSTRAINT product_accessory_accessory_fk FOREIGN KEY (accessory_id) REFERENCES jemser_product(id);


--
-- Name: product_accessory_product_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_accessory
    ADD CONSTRAINT product_accessory_product_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product(id);


--
-- Name: product_class_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_class
    ADD CONSTRAINT product_class_fk FOREIGN KEY (product_class_id) REFERENCES product_class(id);


--
-- Name: product_group_product_group_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY product_group
    ADD CONSTRAINT product_group_product_group_fk FOREIGN KEY (product_group_id) REFERENCES product_group(id) DEFERRABLE;


--
-- Name: product_product_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_product
    ADD CONSTRAINT jemser_product_product_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product(id) DEFERRABLE;


--
-- Name: product_product_group_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_product
    ADD CONSTRAINT jemser_product_product_group_fk FOREIGN KEY (product_group_id) REFERENCES product_group(id);


--
-- Name: project_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_project
    ADD CONSTRAINT project_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: project_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_tender
    ADD CONSTRAINT project_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id) DEFERRABLE;

--
-- Name: business_entity_relationship_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE jemser_tender
  ADD CONSTRAINT business_entity_relationship_fk FOREIGN KEY (business_entity_relationship_id) REFERENCES business_entity_relationship (id) ON UPDATE NO ACTION ON DELETE NO ACTION;


--
-- Name: project_project_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_project
    ADD CONSTRAINT jemser_project_project_fk FOREIGN KEY (jemser_project_id) REFERENCES jemser_project(id) DEFERRABLE;


--
-- Name: ptam_address_category_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_address_map
    ADD CONSTRAINT ptam_address_category_fk FOREIGN KEY (address_category_id) REFERENCES address_category(id);


--
-- Name: ptcdm_contact_detail_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_to_contact_detail_map
    ADD CONSTRAINT ptcdm_contact_detail_fk FOREIGN KEY (contact_detail_id) REFERENCES contact_detail(id);


--
-- Name: ptcdm_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY person_to_contact_detail_map
    ADD CONSTRAINT ptcdm_person_fk FOREIGN KEY (person_id) REFERENCES person(id);


--
-- Name: ptpm_person_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_person_map
    ADD CONSTRAINT ptpm_person_fk FOREIGN KEY (person_id) REFERENCES person(id);


--
-- Name: ptpm_person_role_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_person_map
    ADD CONSTRAINT ptpm_person_role_fk FOREIGN KEY (person_role_id) REFERENCES person_role(id);


--
-- Name: ptpm_project_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project_to_person_map
    ADD CONSTRAINT ptpm_project_fk FOREIGN KEY (jemser_project_id) REFERENCES jemser_project(id);


--
-- Name: request_address_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request
    ADD CONSTRAINT request_address_fk FOREIGN KEY (address_id) REFERENCES address(id);



--
-- Name: request_request_response_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request
    ADD CONSTRAINT request_request_response_fk FOREIGN KEY (selected_response_id) REFERENCES request_response(id) DEFERRABLE;


--
-- Name: request_request_status_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request
    ADD CONSTRAINT request_request_status_fk FOREIGN KEY (request_status_id) REFERENCES request_status(id);


--
-- Name: request_response_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request_response
    ADD CONSTRAINT request_response_business_entity_fk FOREIGN KEY (business_entity_id) REFERENCES business_entity(id);


--
-- Name: request_response_request_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY request_response
    ADD CONSTRAINT request_response_request_fk FOREIGN KEY (request_id) REFERENCES request(id) DEFERRABLE;


--
-- Name: source_business_entity_relationship_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_relationship
    ADD CONSTRAINT source_business_entity_relationship_business_entity_fk FOREIGN KEY (source_business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: target_business_entity_relationship_business_entity_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY business_entity_relationship
    ADD CONSTRAINT target_business_entity_relationship_business_entity_fk FOREIGN KEY (target_business_entity_id) REFERENCES business_entity(id) DEFERRABLE;


--
-- Name: tender_product_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY jemser_tender
    ADD CONSTRAINT jemser_tender_product_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product(id) DEFERRABLE;


--
-- Name: tender_region_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

--ALTER TABLE ONLY jemser_tender
--   ADD CONSTRAINT jemser_tender_region_fk FOREIGN KEY (region_id) REFERENCES region(id) DEFERRABLE;


--CREATE INDEX fki_request_address_fk  ON request   USING btree   (address_id);


--ALTER TABLE ONLY request ADD CONSTRAINT request_pk PRIMARY KEY (id);
ALTER TABLE ONLY request ADD CONSTRAINT request_business_entity_fk FOREIGN KEY (business_entity_id)
      REFERENCES business_entity (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION;
ALTER TABLE ONLY request ADD CONSTRAINT request_person_fk FOREIGN KEY (person_id)
      REFERENCES person (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION;

--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--
CREATE TABLE business_entity_person_to_person_group
(
  id serial NOT NULL,
  business_enity_to_person_map_id integer,
  person_group_category_id integer,
  CONSTRAINT beptpg_pk PRIMARY KEY (id),
  CONSTRAINT beptpg_to_betpm_fk FOREIGN KEY (business_enity_to_person_map_id)
      REFERENCES business_entity_to_person_map (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT beptpg_to_pgc_fk FOREIGN KEY (person_group_category_id)
      REFERENCES person_group_category (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE business_entity_person_to_person_group
  OWNER TO postgres;

 -- Table: request_diary_extension

-- DROP TABLE request_diary_extension;

CREATE TABLE request_diary_extension
(
  id serial NOT NULL,
  account_code text,
  order_number text,
  equipment_details text,
  price_agreed text,
  transport_details text,
  CONSTRAINT request_delivery_extension_pk PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_diary_extension
  OWNER TO postgres;
  
-- Table: request_to_request_diary_extension_map

-- DROP TABLE request_to_request_diary_extension_map;

CREATE TABLE request_to_request_diary_extension_map
(
  id serial NOT NULL,
  request_id integer,
  request_diary_extension_id integer,
  CONSTRAINT id PRIMARY KEY (id),
  CONSTRAINT rtdem_request_diary_extension_fk FOREIGN KEY (request_diary_extension_id)
      REFERENCES request_diary_extension (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT rtrdem_to_request_fk FOREIGN KEY (request_id)
      REFERENCES request (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_to_request_diary_extension_map
  OWNER TO postgres;

-- Table: run_category

-- DROP TABLE run_category;

CREATE TABLE run_category
(
  id integer NOT NULL,
  description text,
  run_time time without time zone,
  CONSTRAINT run_category_pk PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE run_category
  OWNER TO postgres;  
  
  
-- Table: request_to_run_category_map

-- DROP TABLE request_to_run_category_map;

CREATE TABLE request_to_run_category_map
(
  id serial NOT NULL,
  request_id integer,
  run_category_id integer,
  CONSTRAINT request_to_run_category_map_pk PRIMARY KEY (id),
  CONSTRAINT rtrcm_to_request_fk FOREIGN KEY (request_id)
      REFERENCES request (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT rtrm_to_run_category_fk FOREIGN KEY (run_category_id)
      REFERENCES run_category (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_to_run_category_map
  OWNER TO postgres;


  


 CREATE TABLE jemser_action
(
  id serial NOT NULL,
  action_type_id integer,
  action_priority_id integer,
  date_created timestamp with time zone,
  date_scheduled timestamp with time zone,
  date_completed timestamp with time zone,
  seq integer,
  actor_person_id integer,
  actee_person_id integer,
  comment text,
  created_by_person_id integer,
  request_id integer,
  CONSTRAINT jemser_action_pkey PRIMARY KEY (id),
  CONSTRAINT fk_jemser_action_actee_person_id FOREIGN KEY (actee_person_id)
      REFERENCES person (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_jemser_action_action_priority_id FOREIGN KEY (action_priority_id)
      REFERENCES action_priority (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_jemser_action_action_type_id FOREIGN KEY (action_type_id)
      REFERENCES action_type (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_jemser_action_actor_person_id FOREIGN KEY (actor_person_id)
      REFERENCES person (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_jemser_action_created_by_person_id FOREIGN KEY (created_by_person_id)
      REFERENCES person (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_jemser_action_request_id FOREIGN KEY (request_id)
      REFERENCES request (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE CASCADE
)
WITH (
  OIDS=FALSE
);
ALTER TABLE jemser_action
  OWNER TO postgres;



-- add success field for jemser actions 
ALTER TABLE jemser_action  ADD COLUMN success boolean;

-- add link to the business_entity who is associated with this action
ALTER TABLE jemser_action
  ADD COLUMN responder_business_entity_id integer;
ALTER TABLE jemser_action
  ADD CONSTRAINT jemser_action_responder_business_entity_fk FOREIGN KEY (responder_business_entity_id) REFERENCES business_entity (id) ON UPDATE NO ACTION ON DELETE NO ACTION;

-- person password table

CREATE TABLE public.person_credentials
(
   id serial, 
   username text, 
   password text, 
   apikey text, 
   person_id integer, 
   CONSTRAINT person_credentials_pk PRIMARY KEY (id), 
   CONSTRAINT pc_to_person_fk FOREIGN KEY (person_id) REFERENCES person (id) ON UPDATE NO ACTION ON DELETE NO ACTION
) 
WITH (
  OIDS = FALSE
)
;
ALTER TABLE public.person_credentials
  OWNER TO postgres;
  
  

  
-- update request 
-- request type foreign id
ALTER TABLE request  ADD COLUMN request_type_id integer;
ALTER TABLE request  ADD CONSTRAINT request_to_request_type_fk FOREIGN KEY (request_type_id) REFERENCES request_type (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
-- request created by person
ALTER TABLE request  ADD COLUMN created_by_person_id integer;
ALTER TABLE request  ADD FOREIGN KEY (created_by_person_id) REFERENCES person (id) ON UPDATE NO ACTION ON DELETE NO ACTION; 
-- jemser_product foreign id
ALTER TABLE request  ADD COLUMN jemser_product_id integer;
-- jemser_product qty
ALTER TABLE request  ADD COLUMN jemser_product_qty numeric(10,2);
-- jemser project foreign id
ALTER TABLE request  ADD COLUMN jemser_project_id integer;
-- request expiry date
ALTER TABLE request  ADD COLUMN response_deadline timestamp with time zone;
-- request projected completion date
ALTER TABLE request  ADD COLUMN completion_date timestamp with time zone;
-- business_entity currently handling request
ALTER TABLE request  ADD COLUMN responder_business_entity_id integer;
-- if request is cloned this field shows the parent request that it was cloned from
ALTER TABLE request  ADD COLUMN parent_request_id integer;
-- Initial creation_date , the normal creation_date will change each time request is submitted to new supplier
ALTER TABLE request  ADD COLUMN initial_creation_date timestamp with time zone;
-- Generic request text field for example PO number
ALTER TABLE request  ADD COLUMN request_reference text;
-- Copy of the rate for jemser_product at the time of request creation
ALTER TABLE request  ADD COLUMN rate numeric(10,4);

-- Constraints
ALTER TABLE request
  ADD CONSTRAINT request_jemser_product_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
ALTER TABLE request
  ADD CONSTRAINT request_jemser_project_fk FOREIGN KEY (jemser_project_id) REFERENCES jemser_project (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
ALTER TABLE request
  ADD CONSTRAINT request_responder_business_entity_fk FOREIGN KEY (responder_business_entity_id) REFERENCES business_entity (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
ALTER TABLE request
  ADD CONSTRAINT request_parent_request_fk FOREIGN KEY (parent_request_id) REFERENCES request (id) ON UPDATE NO ACTION ON DELETE NO ACTION;

  
  

ALTER TABLE jemser_product ALTER COLUMN jemser_product_id DROP NOT NULL;

ALTER TABLE product_group    ALTER COLUMN product_group_id DROP NOT NULL;
ALTER TABLE product_group   ALTER COLUMN optlock DROP NOT NULL;
ALTER TABLE jemser_product   ALTER COLUMN optlock DROP NOT NULL;
ALTER TABLE jemser_project ALTER COLUMN optlock DROP NOT NULL;


ALTER TABLE request RENAME rate  TO daily_rate;
ALTER TABLE request ADD COLUMN weekly_rate numeric(10,4);
ALTER TABLE request ADD COLUMN sales numeric(10,4);
-- mapping tables 

-- business entity to cust 
CREATE TABLE business_entity_to_cust_map
(
  id serial NOT NULL,
  business_entity_id integer,
  cust_id integer,
  customer_code text,
  CONSTRAINT business_entity_to_cust_map_pk PRIMARY KEY (id),
  CONSTRAINT betcm_be_fk FOREIGN KEY (business_entity_id)
      REFERENCES business_entity (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT betcm_c_fk FOREIGN KEY (cust_id)
      REFERENCES cust (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE business_entity_to_cust_map
  OWNER TO postgres;
ALTER TABLE business_entity_to_cust_map
  ADD COLUMN company_entity_id integer;
  
-- address to custsite

CREATE TABLE address_to_custsite_map
(
  id serial NOT NULL,
  address_id integer,
  custsite_id integer,
  CONSTRAINT address_to_custsite_pk PRIMARY KEY (id),
  CONSTRAINT atc_address_fk FOREIGN KEY (address_id)
      REFERENCES address (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT atc_custsite_fk FOREIGN KEY (custsite_id)
      REFERENCES custsite (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE address_to_custsite_map
  OWNER TO postgres;
 ALTER TABLE address_to_custsite_map
  ADD COLUMN company_entity_id integer;
  
-- person to contact 


CREATE TABLE person_to_contact_map
(
  id serial NOT NULL,
  person_id integer,
  contact_id integer,
  CONSTRAINT person_to_contact_pk PRIMARY KEY (id),
  CONSTRAINT ptcm_contact_fk FOREIGN KEY (contact_id)
      REFERENCES contact (nsuk) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT ptcm_person_fk FOREIGN KEY (person_id)
      REFERENCES person (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE person_to_contact_map
  OWNER TO postgres;
 ALTER TABLE person_to_contact_map
  ADD COLUMN company_entity_id integer;

  
  
  
-- Table: business_entity_configuration

-- DROP TABLE business_entity_configuration;

CREATE TABLE business_entity_configuration
(
  id serial NOT NULL,
  business_entity_id integer,
  global_expiry integer,
  approval_required boolean,
  purchase_order_required boolean,
  CONSTRAINT business_entity_configuration_pk PRIMARY KEY (id),
  CONSTRAINT business_entity_configuration_to_be_fk FOREIGN KEY (business_entity_id)
      REFERENCES business_entity (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE business_entity_configuration
  OWNER TO postgres;
  
  
ALTER TABLE business_entity_product  ADD CONSTRAINT business_entity_product_to_jp_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product (id) ON UPDATE NO ACTION ON DELETE NO ACTION;  
  
--
-- PostgreSQL database dump complete
--
CREATE TABLE request_rating
(
  id serial NOT NULL,
  business_entity_id integer,
  request_id integer,
  punctuality_rating integer,
  equipment_condition_rating integer,
  equipment_accuracy_rating integer,
  comment text,
  CONSTRAINT request_rating_pk PRIMARY KEY (id),
  CONSTRAINT rr_to_business_entity_fk FOREIGN KEY (business_entity_id)
      REFERENCES business_entity (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT rr_to_request_fk FOREIGN KEY (request_id)
      REFERENCES request (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_rating
  OWNER TO postgres;

ALTER TABLE jemser_product
  ADD COLUMN product_class_id integer;
ALTER TABLE jemser_product
  ADD CONSTRAINT jp_to_product_class_fk FOREIGN KEY (product_class_id) REFERENCES product_class (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
  ALTER TABLE jemser_product
  ADD COLUMN cod text;

  ALTER TABLE product_group
   ALTER COLUMN product_group_id DROP NOT NULL;

  
CREATE TABLE public.jemser_product_to_hire_or_product_map
(
   id serial, 
   jemser_product_id integer, 
   product_type_id integer, 
   pdesc_id integer, 
   business_entity_id integer,
   singles_id integer,
   CONSTRAINT jp_to_h_or_p_pk PRIMARY KEY (id)
) 
WITH (
  OIDS = FALSE
)
;

CREATE TABLE public.request_to_jemser_product_map
(
   id serial, 
   request_id integer, 
   jemser_product_id integer, 
   qty numeric(10,2), 
   comment text, 
   daily numeric(10,4), 
   day2 numeric(10,4), 
   day3 numeric(10,4), 
   day4 numeric(10,4), 
   day5 numeric(10,4), 
   day6 numeric(10,4), 
   weekly numeric(10,4), 
   CONSTRAINT req_to_jem_prod_map_pk PRIMARY KEY (id), 
   CONSTRAINT req_to_jem_prod_map_request_fk FOREIGN KEY (request_id) REFERENCES request (id) ON UPDATE NO ACTION ON DELETE NO ACTION, 
   CONSTRAINT req_to_jem_prod_map_jproduct_fk FOREIGN KEY (jemser_product_id) REFERENCES jemser_product (id) ON UPDATE NO ACTION ON DELETE NO ACTION
) 
WITH (
  OIDS = FALSE
)
;
ALTER TABLE request_to_jemser_product_map ADD COLUMN crosshire boolean;
ALTER TABLE request_to_jemser_product_map ADD COLUMN overridedescription text;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN line_number integer;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN package_name text;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN package_seq integer;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN qty_available numeric(10,2);
-- 30/03/2017
ALTER TABLE request_to_jemser_product_map  ADD COLUMN qty_collected numeric(10,2);
--07/05/2017
ALTER TABLE request_to_jemser_product_map  ADD COLUMN from_date time with time zone;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN to_date time with time zone;
ALTER TABLE request_to_jemser_product_map  ADD COLUMN detailline_id integer;


CREATE TABLE mapping_document_type
(
  id integer NOT NULL,
  description text,
  CONSTRAINT mapping_document_type_pk PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE mapping_document_type
  OWNER TO postgres;
  
CREATE TABLE request_to_document_map
(
  id serial NOT NULL,
  request_id integer,
  mapping_document_type_id integer,
  document_number integer,
  document_id integer,
  business_entity_id integer,
  CONSTRAINT request_to_document_map_pk PRIMARY KEY (id),
  CONSTRAINT request_to_document_map_fk1 FOREIGN KEY (request_id)
      REFERENCES request (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT request_to_document_map_fk2 FOREIGN KEY (mapping_document_type_id)
      REFERENCES mapping_document_type (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT request_to_document_map_fk4 FOREIGN KEY (business_entity_id)
      REFERENCES business_entity (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);
ALTER TABLE request_to_document_map
  OWNER TO postgres;
  
  CREATE TABLE document_bean_queue
(
  id serial NOT NULL,
  status integer,
  document_bean text,
  CONSTRAINT document_bean_queue_pk PRIMARY KEY (id)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE document_bean_queue
  OWNER TO postgres;
ALTER TABLE document_bean_queue  ADD COLUMN request_id integer;
ALTER TABLE document_bean_queue  ADD COLUMN error_text text;
ALTER TABLE document_bean_queue  ADD COLUMN queue_type integer;



CREATE TABLE request_to_patient_map
(
   id serial, 
   request_id integer, 
   patient_id integer, 
   CONSTRAINT request_to_person_map_pkey PRIMARY KEY (id) USING INDEX TABLESPACE pg_default, 
   CONSTRAINT patient_id_to_person_fkey FOREIGN KEY (patient_id) REFERENCES person (id) ON UPDATE NO ACTION ON DELETE NO ACTION, 
   CONSTRAINT request_id_to_request_fkey FOREIGN KEY (request_id) REFERENCES request (id) ON UPDATE NO ACTION ON DELETE NO ACTION
) 
WITH (
  OIDS = FALSE
)
;
ALTER TABLE public.request_to_patient_map
  OWNER TO postgres;


CREATE TABLE public.chead_to_person_map
(
   id serial, 
   person_id integer, 
   chead_location integer, 
   chead_contract integer, 
   reference text, 
   CONSTRAINT cheadtopersonmappk PRIMARY KEY (id), 
   CONSTRAINT chtopfk1 FOREIGN KEY (person_id) REFERENCES person (id) ON UPDATE NO ACTION ON DELETE NO ACTION, 
   CONSTRAINT chtopfk2 FOREIGN KEY (chead_location, chead_contract) REFERENCES chead (location, contract) ON UPDATE NO ACTION ON DELETE NO ACTION
) 
WITH (
  OIDS = FALSE
)
;

CREATE TABLE public.cust_order_to_person_map
(
   id serial, 
   person_id integer, 
   cust_order_id integer, 
   reference text, 
   CONSTRAINT custordertopersonmappk PRIMARY KEY (id), 
   CONSTRAINT cotopfk1 FOREIGN KEY (person_id) REFERENCES person (id) ON UPDATE NO ACTION ON DELETE NO ACTION, 
   CONSTRAINT cotopfk2 FOREIGN KEY (cust_order_id) REFERENCES cust_order (nsuk) ON UPDATE NO ACTION ON DELETE NO ACTION
) 
WITH (
  OIDS = FALSE
)
;