create extension postgres_fdw

create server fdwghhire foreign data wrapper postgres_fdw options ( host 'localhost',dbname 'ghhire' , port '5432' )


create user mapping for postgres server fdwghhire options ( user 'postgres',password 'prevgres' )


create foreign table remotehirecust 
(
  depot integer NOT NULL,
  cod character(7) NOT NULL,
  nam character(30),
  add1 text,
  add2 text,
  add3 text,
  add4 text,
  statement character(1),
  last_pay numeric(16,2),
  last_paid date,
  hire_disc numeric(4,2) NOT NULL,
  sales_disc numeric(4,2) NOT NULL,
  suspend character(1),
  unallocated numeric(16,2),
  balance numeric(16,2),
  order_req character(1),
  account_type character(1),
  notes integer,
  cr_limit numeric(16,2),
  price_cat character(1),
  policy character(8),
  calendar character(8),
  new_account character(1),
  tender character(8),
  bad_debt character(1),
  location integer,
  cc_status integer,
  credit_days integer,
  period date,
  dat date,
  operator integer,
  vat_exempt character(1),
  charge_fuel character(1),
  charge_deliv character(1),
  consolidate integer,
  staff integer NOT NULL DEFAULT 0,
  cust_status_id integer,
  statement_form integer NOT NULL DEFAULT 0,
  include_images character(1) NOT NULL DEFAULT 'Y'::bpchar,
  id serial NOT NULL
)

server fdwghhire options ( table_name 'cust' );


CREATE FOREIGN TABLE remotehirecustsite
(
  depot integer NOT NULL,
  cust character(7) NOT NULL,
  site integer NOT NULL,
  description text,
  calendar character(8),
  distance integer,
  active character(1),
  add1 text,
  add2 text,
  add3 text,
  add4 text,
  phone character(30),
  fax character(30),
  project integer,
  id serial NOT NULL
)


server fdwghhire options ( table_name 'custsite' );

CREATE FOREIGN TABLE remotehirecontact
(
  depot integer,
  cod character(7),
  typ character(1),
  nam character(20),
  phone character(30),
  fax character(30),
  greeting character(10),
  nsuk serial NOT NULL,
  email character(90),
  pdf character(1),
  csv character(1),
  xsl character(1),
  mdb character(1),
  plantlist integer NOT NULL
)

server fdwghhire options ( table_name 'contact' );



create foreign table remote_hire_dept 
(
  nsuk serial NOT NULL,
  descr character(30),
  nominal character(6)
)

server fdwghhire options ( table_name 'hire_dept' );


create foreign table remote_hire_dept_group
(
  nsuk serial NOT NULL,
  hire_dept integer,
  descr character(30),
  nominal character(6)
)

server fdwghhire options ( table_name 'hire_dept_group' );


create foreign table remote_pdesc
(
  asset_reg character(1),
  cod character(4) NOT NULL,
  desc1 text,
  desc2 character(30),
  desc3 character(30),
  vcode integer,
  typ character(1),
  deposit numeric(16,2),
  nominal character(6),
  hireperiod character(1),
  dep_months integer,
  selling_price numeric(16,2),
  msg_typ character(2),
  id serial NOT NULL
)

server fdwghhire options ( table_name 'pdesc' );


create foreign table remote_pdesc_ext
(
  pdesc character(4) NOT NULL,
  dept_group integer,
  auto_depreciate integer
)

server fdwghhire options ( table_name 'pdesc_ext' );

create foreign table remote_singles
(
  asset_reg character(1) NOT NULL,
  pdesc character(4) NOT NULL,
  cod character(6) NOT NULL,
  serial_no character(100),
  last_service_date date,
  service_period character(20),
  last_hire_date date,
  stat integer,
  picked character(1),
  location smallint,
  ref1 character(30),
  ref2 character(30),
  ref3 character(30),
  ref4 character(30),
  barcode character(30),
  date1 date,
  date2 date,
  lock_count integer NOT NULL,
  id serial NOT NULL
)

server fdwghhire options ( table_name 'singles' );

create foreign table remote_dept
(
  nsuk serial NOT NULL,
  cod character(3),
  descr character(30)
)

server fdwghhire options ( table_name 'dept' );


create foreign table remote_dept_group
(
  nsuk serial NOT NULL,
  cod character(3),
  dept integer,
  descr character(30)
)

server fdwghhire options ( table_name 'dept_group' );

create foreign table remote_product
(
  nsuk serial NOT NULL,
  cod character(7),
  description text,
  vcode integer,
  sell numeric(16,4),
  cost numeric(16,4),
  sales_nominal character(6),
  invoice_when character(1),
  grp character(8),
  unit_cost numeric(16,4),
  last_cost numeric(16,4),
  stock_value numeric(16,4),
  purchase_nominal character(6),
  stock_type character(1),
  supplier character(6),
  supplier_ref character(16),
  lead_time integer,
  purchase_qty integer,
  stock_unit character(10),
  stock_lock character(1),
  reorder_level integer,
  open_level integer,
  open_contract integer,
  stock_level integer,
  stock_contract integer,
  stock_batches integer,
  stock_freeze integer,
  stock_nominal character(6),
  alpha_key character(8),
  barcode character(13),
  dept_group integer
)

server fdwghhire options ( table_name 'product' );

create foreign table remote_product_type
(
  nsuk serial NOT NULL,
  plu character(7),
  product integer NOT NULL,
  descr text,
  last_sell_date date,
  unit_cost numeric(16,4) NOT NULL,
  last_cost numeric(16,4),
  stock_value numeric(16,4),
  stock_unit character(10),
  stock_lock character(1),
  reorder_level integer,
  open_level integer,
  open_contract integer,
  stock_level integer,
  stock_contract integer,
  stock_batches integer,
  stock_freeze integer,
  curr_cost_price numeric(16,4),
  curr_sell_price numeric(16,4),
  curr_vat_price numeric(16,4),
  redundant character(1)
)

server fdwghhire options ( table_name 'product_type' );




  
create foreign table remote_custsite_ext
(
  id serial NOT NULL,
  custsite_id integer,
  lat numeric(20,17),
  lng numeric(20,17)
)
server fdwghhire options ( table_name 'custsite_ext' );



create foreign table remote_stock
(
  nsuk serial NOT NULL,
  product_type integer NOT NULL,
  location integer NOT NULL,
  qty_physical numeric(16,2) NOT NULL,
  qty_allocated numeric(16,2),
  qty_onorder numeric(16,2),
  qty_onhire numeric(16,2),
  qty_uninspected numeric(16,2),
  qty_oncustorder numeric(16,2)
)
server fdwghhire options ( table_name 'stock' );

-- in order to insert onto the remote stock table we must update the trigger function on the remote database its 
-- not schema specific.

DROP TRIGGER stock_trigger ON stock;

DROP FUNCTION stock_triggerfunction();

CREATE OR REPLACE FUNCTION stock_triggerfunction()
  RETURNS trigger AS
$BODY$
declare product_type_id integer;
        
begin
		
    if (TG_OP = 'INSERT') THEN
    select nsuk
    into product_type_id
    from "public".product_type
    where  nsuk = new."product_type";
	 perform 1
	from "public".product_type_trig
	where id = new."product_type";
	  
	if not found then  
	
	insert into "public".product_type_trig (id, date_time, paction) values (product_type_id, NOW(), 'INSERT' ); 
	else
	    update "public".product_type_trig set date_time = NOW(), paction = 'INSERT' where id = product_type_id ;
        end if;
	
	        
    ELSEIF (TG_OP = 'UPDATE') THEN
    select nsuk
    into product_type_id
    from "public".product_type
    where  nsuk = old."product_type";
    perform 1
	from "public".product_type_trig
	where id = old."product_type";
	  
	if not found then
   
	    insert into "public".product_type_trig (id, date_time, pAction ) values (product_type_id, NOW(), 'UPDATE' ); 
	else
	    update "public".product_type_trig set date_time = NOW(), paction = 'UPDATE' where id = product_type_id;
        end if;
        
    ELSEIF (TG_OP = 'DELETE') THEN
    select nsuk
    into product_type_id
    from "ghhire".product_type
    where  nsuk = old."product_type";
     perform 1
	from "public".product_type_trig
	where id = old."product_type";
        if not found then
	    insert into "public".product_type_trig (id, date_time, paction) values (product_type_id, NOW(), 'DELETE' ); 
	else
	    update "public".product_type_trig set date_time = NOW(), paction = 'DELETE' where id = product_type_id;
        end if;
    END IF;

    return NULL;  

end;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION stock_triggerfunction()
  OWNER TO postgres;

CREATE TRIGGER stock_trigger
  AFTER INSERT OR UPDATE OR DELETE
  ON stock
  FOR EACH ROW

  EXECUTE PROCEDURE stock_triggerfunction();